@@ -9,6 +9,7 @@ import qualified GI.Gdk.Config as Gdk
 import qualified GI.Gio.Config as Gio
 import qualified GI.Gtk.Config as Gtk
 import qualified GI.Pango.Config as Pango
+import qualified GI.Cairo.Config as Cairo
 
 
 main :: IO ()
@@ -16,8 +17,8 @@ main = setupBinding name version pkgName pkgVersion verbose overridesFile inheri
   where name = "Vte"
         version = "2.91"
         pkgName = "gi-vte"
-        pkgVersion = "2.91.31"
+        pkgVersion = "2.91.33"
         overridesFile = Just "Vte.overrides"
         verbose = False
         outputDir = Nothing
-        inheritedOverrides = [TaggedOverride "inherited:Atk" Atk.overrides, TaggedOverride "inherited:GLib" GLib.overrides, TaggedOverride "inherited:GObject" GObject.overrides, TaggedOverride "inherited:Gdk" Gdk.overrides, TaggedOverride "inherited:Gio" Gio.overrides, TaggedOverride "inherited:Gtk" Gtk.overrides, TaggedOverride "inherited:Pango" Pango.overrides]
+        inheritedOverrides = [TaggedOverride "inherited:Atk" Atk.overrides, TaggedOverride "inherited:GLib" GLib.overrides, TaggedOverride "inherited:GObject" GObject.overrides, TaggedOverride "inherited:Gdk" Gdk.overrides, TaggedOverride "inherited:Gio" Gio.overrides, TaggedOverride "inherited:Gtk" Gtk.overrides, TaggedOverride "inherited:Pango" Pango.overrides, TaggedOverride "inherited:Cairo" Cairo.overrides]
